@@ -1,6 +1,7 @@
 from ..hooks import AlignerPlusCHook, RTNHook
 from ..utils.common_functions import check_domain
 from .base_adapter import BaseGCAdapter
+from .utils import with_opt
 
 
 class Aligner(BaseGCAdapter):
@@ -11,7 +12,8 @@ class Aligner(BaseGCAdapter):
     hook_cls = AlignerPlusCHook
 
     def init_hook(self, hook_kwargs):
-        self.hook = self.hook_cls(opts=list(self.optimizers.values()), **hook_kwargs)
+        opts = with_opt(list(self.optimizers.keys()))
+        self.hook = self.hook_cls(opts, **hook_kwargs)
 
 
 class RTN(Aligner):
