@@ -2,6 +2,7 @@ from ..hooks import CDANNEHook, DANNEHook, DANNHook, GVBEHook, GVBHook
 from ..layers import ModelWithBridge
 from .base_adapter import BaseGCDAdapter
 from .gan import CDAN
+from .utils import with_opt
 
 
 class DANN(BaseGCDAdapter):
@@ -12,7 +13,8 @@ class DANN(BaseGCDAdapter):
     hook_cls = DANNHook
 
     def init_hook(self, hook_kwargs):
-        self.hook = self.hook_cls(opts=list(self.optimizers.values()), **hook_kwargs)
+        opts = with_opt(list(self.optimizers.keys()))
+        self.hook = self.hook_cls(opts=opts, **hook_kwargs)
 
 
 class DANNE(DANN):
