@@ -1,5 +1,6 @@
 from ..hooks import MCDHook
 from .base_adapter import BaseGCAdapter
+from .utils import with_opt
 
 
 class MCD(BaseGCAdapter):
@@ -17,5 +18,5 @@ class MCD(BaseGCAdapter):
 
     def init_hook(self, hook_kwargs):
         self.hook = self.hook_cls(
-            g_opts=[self.optimizers["G"]], c_opts=[self.optimizers["C"]], **hook_kwargs
+            g_opts=with_opt(["G"]), c_opts=with_opt(["C"]), **hook_kwargs
         )
