@@ -1,10 +1,10 @@
 import ignite.distributed as idist
-import torch
 from ignite.engine import Engine, Events
 from ignite.handlers import TerminateOnNan
 
 from ...datasets import DataloaderCreator
 from ...utils import common_functions as c_f
+from .. import utils as f_utils
 from . import utils as i_g
 from .loggers import IgniteEmptyLogger
 
@@ -26,6 +26,7 @@ class Ignite:
         log_freq=50,
         with_pbars=True,
         device=None,
+        auto_dist=True,
     ):
         """
         Arguments:
@@ -46,13 +47,13 @@ class Ignite:
         self.trainer_init()
         self.collector_init()
         self.dist_init_done = False
-        if device is None:
+        if device is None and auto_dist:
             self.dist_init()
         self.temp_events = []
 
     def training_step(self, engine, batch):
         batch = c_f.batch_to_device(batch, self.device)
-        return self.adapter.training_step(batch, self)
+        return self.adapter.training_step(batch)
 
     def before_training_starts(self, engine):
         self.adapter.before_training_starts(self)
@@ -86,20 +87,10 @@ class Ignite:
         )
 
     def collector_init(self):
-        self.labeled_collector = Engine(
-            self.get_labeled_collector_step(self.adapter.inference)
-        )
-        self.unlabeled_collector = Engine(
-            self.get_unlabeled_collector_step(self.adapter.inference)
-        )
-        i_g.set_loggers_and_pbars(self, ["labeled_collector", "unlabeled_collector"])
+        self.collector = Engine(self.get_collector_step(self.adapter.inference))
+        i_g.set_loggers_and_pbars(self, ["collector"])
         i_g.register(
-            self.labeled_collector,
-            Events.EPOCH_STARTED,
-            self.set_to_eval(self.adapter.models),
-        )
-        i_g.register(
-            self.unlabeled_collector,
+            self.collector,
             Events.EPOCH_STARTED,
             self.set_to_eval(self.adapter.models),
         )
@@ -211,9 +202,7 @@ class Ignite:
             ),
         )
 
-    def evaluate_best_model(
-        self, datasets, validator, saver, epoch, dataloader_creator=None
-    ):
+    def evaluate_best_model(self, datasets, validator, saver, dataloader_creator=None):
         c_f.LOGGER.info("***EVALUATING BEST MODEL***")
         dataloader_creator = c_f.default(dataloader_creator, DataloaderCreator())
         dataloaders = dataloader_creator(**datasets)
@@ -221,45 +210,15 @@ class Ignite:
         collected_data = i_g.collect_from_dataloaders(
             self, dataloaders, validator.required_data
         )
-        return i_g.get_validation_score(collected_data, validator, epoch)
+        return i_g.get_validation_score(collected_data, validator)
 
-    def create_output_dict(self, features, logits):
-        return {
-            "features": features,
-            "logits": logits,
-            "preds": torch.softmax(logits, dim=1),
-        }
-
-    def get_x_collector_step(self, inference, name):
+    def get_collector_step(self, inference):
         def collector_step(engine, batch):
-            with torch.no_grad():
-                batch = c_f.batch_to_device(batch, self.device)
-                features, logits = inference(
-                    batch[f"{name}_imgs"], domain=batch[f"{name}_domain"]
-                )
-            output = self.create_output_dict(features, logits)
-            output["domain"] = batch[f"{name}_domain"]
-            labels_key = f"{name}_labels"
-            if labels_key in batch:
-                output["labels"] = batch[labels_key]
-            return output
+            batch = c_f.batch_to_device(batch, self.device)
+            return f_utils.collector_step(inference, batch, f_utils.create_output_dict)
 
         return collector_step
 
-    def get_labeled_collector_step(self, inference):
-        return self.get_x_collector_step(inference, "src")
-
-    def get_unlabeled_collector_step(self, inference):
-        return self.get_x_collector_step(inference, "target")
-
-    def get_collector(self, dataset):
-        dataset_output = dataset[0]
-        return (
-            self.labeled_collector
-            if len(dataset_output) == 4
-            else self.unlabeled_collector
-        )
-
     def set_to_train(self, models):
         def handler(engine):
             c_f.LOGGER.info("Setting models to train() mode")
