@@ -345,11 +345,14 @@ def zero_loss():
     return torch.tensor(0, dtype=torch.float, requires_grad=True)
 
 
-def zero_back_step(loss, optimizers):
+def zero_back_step(loss, optimizers, custom_backward=None):
     for x in optimizers:
         x.zero_grad()
     if loss.grad_fn is not None:
-        loss.backward()
+        if custom_backward:
+            custom_backward(loss)
+        else:
+            loss.backward()
         for x in optimizers:
             x.step()
 
@@ -488,10 +491,13 @@ def dicts_are_overlapping(x, y, return_overlap=False):
 
 
 def assert_dicts_are_disjoint(*x):
-    for a, b in itertools.combinations(x, 2):
-        is_overlap, overlap = dicts_are_overlapping(a, b, True)
-        if is_overlap:
-            raise KeyError(f"dicts have overlapping keys {overlap}")
+    output, total_len = {}, 0
+    for y in x:
+        output.update(y)
+        total_len += len(y)
+    if len(output) != total_len:
+        raise KeyError(f"dicts have overlapping keys")
+    return output
 
 
 def extract_progress(compressed_obj):
